#from AMCowmvg import app

try:
    from __init__ import app
except:
    print("")

try:
    from AMCowmvg.__init__ import app
except:
    print("")    
#testing testing


def runApp():
    if __name__ == '__main__':
        app.run(debug=True, host='127.0.0.1')

runApp()


from flask_wtf import FlaskForm
from flask_wtf.file import FileField, FileAllowed
from wtforms import *
from wtforms.validators import *

class addReaction(FlaskForm):
    reactNames = StringField('Reactant Names:', validators=[DataRequired()])
    startingReactConcs = StringField('Starting Reactant Concentrations:', validators=[DataRequired()])
    fixedReactConc = StringField('Fixed Reactant Names:', validators=[DataRequired()])
    productNames = StringField('Product Names:', validators=[DataRequired()])
    startingProductConcs = StringField('Starting Product Concentrations:', validators=[DataRequired()])
    fixedProductConc = StringField('Fixed Product Names:', validators=[DataRequired()])
    #reactionConstant = FloatField('Reaction Constant:', validators=[DataRequired()])
    reactionConstant = StringField('Reaction Constant:', validators=[DataRequired()])
    reversible = BooleanField('Reversible')

    submit = SubmitField('Add Reaction')

class submit(FlaskForm):
    submit2 = SubmitField('Run Simulation')

class reset(FlaskForm):
    submit3 = SubmitField('Reset Model')

class upload(FlaskForm):
    model = FileField('Upload an Antimony Text File', validators=[FileAllowed(['txt']), DataRequired()])
    submit4 = SubmitField('Finish Model Upload')

class SBML(FlaskForm):
    model = StringField('SBML File Link')
    submit5 = SubmitField('Submit SBML File')


from flask import Flask

app = Flask(__name__)
app.config['SECRET_KEY'] = 'banana'

#from AMCowmvg import routes
import AMCowmvg.routes

#try:
#    import AMCowmvg.routes
#except:
#    print("Local Execution Occured")

#try:
#    import routes
#except:
#    print("Online Execution Occured")